@@ -1,14 +1,11 @@
-
 #
-# renv 1.0.3.9000 [rstudio/renv#4b11818]: A dependency management toolkit for R.
-# Generated using `renv:::vendor()` at 2023-10-31 16:35:16.988562.
+# renv 1.1.5.9000 [rstudio/renv#4c63ee7]: A dependency management toolkit for R.
+# Generated using `renv:::vendor()` at 2025-12-12 13:03:25.497218.
 #
 
-
 renv <- new.env(parent = new.env())
 
-renv$initialize <- function() {
-
+renv$initialize <- function(libname, pkgname) {
   # set up renv + imports environments
   attr(renv, "name") <- "embedded:renv"
   attr(parent.env(renv), "name") <- "imports:renv"
@@ -17,6 +14,8 @@ renv$initialize <- function() {
   imports <- list(
     tools = c(
       "file_ext",
+      "md5sum",
+      "package_dependencies",
       "pskill",
       "psnice",
       "write_PACKAGES"
@@ -70,13 +69,15 @@ renv$initialize <- function() {
   # initialize metadata
   renv$the$metadata <- list(
     embedded = TRUE,
-    version = structure("1.0.3.9000", sha = "4b11818ca81897f10bf1def73db6b69c9fd1af0f")
+    version = structure(
+      "1.1.5.9000",
+      sha = "4c63ee794a768911ea470950dafd20368c862155"
+    )
   )
 
   # run our load / attach hooks so internal state is initialized
-  renv$renv_zzz_load()
+  renv$.onLoad(libname, pkgname)
 
   # remove our initialize method when we're done
   rm(list = "initialize", envir = renv)
-
 }
