@@ -9,7 +9,6 @@
 #' @importFrom utils head modifyList flush.console
 #' @importFrom stats predict
 #' @importFrom vctrs vec_slice vec_sort
-#' @importFrom magrittr %>%
 #' @importFrom glue glue
 #' @importFrom glue glue_collapse
 #' @importFrom generics required_pkgs
@@ -24,17 +23,24 @@ generics::augment
 #' @export
 generics::required_pkgs
 
-globalVariables(c("pr", ".metric", ".pred", "price", "tidy",
-                  "term", "estimate", "terms"))
+globalVariables(c(
+  "pr",
+  ".metric",
+  ".pred",
+  "price",
+  "tidy",
+  "term",
+  "estimate",
+  "terms"
+))
 
 ## to avoid NOTE about "All declared Imports should be used."
 rapidoc_function_for_note <- function() {
-    rapidoc::rapidoc_spec()
+  rapidoc::rapidoc_spec()
 }
 
 release_bullets <- function() {
-    c(
-        'Update renv with `renv:::vendor()`'
-    )
+  c(
+    'Update renv with `renv:::vendor()`'
+  )
 }
-
